@@ -69,12 +69,12 @@ using namespace arma;
 //' cat("package 'microbenchmark' not available\n")
 //'}
 // [[Rcpp::export]]
-NumericMatrix mmvstpdfC(arma::mat x,
-                        arma::mat xi,
-                        arma::mat psi,
-                        List sigma,
-                        NumericVector df,
-                        bool Log=true){
+NumericMatrix mmvstpdfC(const arma::mat & x,
+                        const arma::mat & xi,
+                        const arma::mat & psi,
+                        const List & sigma,
+                        const NumericVector & df,
+                        const bool & Log=true){
 
     int p = x.n_rows;
     int n = x.n_cols;
@@ -107,7 +107,7 @@ NumericMatrix mmvstpdfC(arma::mat x,
             double part1 = log(2.0) + (-(dftemp + p)/2.0)*log(1.0 + quadform/dftemp) + a + logSqrtDetvarcovM ;
             //double part1 = 2*pow((1 + quadform/dftemp),(-(dftemp + p)/2))*exp(a+logSqrtDetvarcovM);
             mat quant = trans(alph)*diagmat(1/sqrt(diagvec(omega)))*x_i*sqrt((dftemp + p)/(dftemp + Qy));
-            double part2 = ::Rf_pt(quant(0,0), (dftemp + p) , 1, 1);
+            double part2 = ::Rf_pt(quant(0,0), (dftemp + p), 1, 1);
             if (!Log) {
                 y(k,i) = exp(part1 + part2);
             } else{
@@ -117,5 +117,7 @@ NumericMatrix mmvstpdfC(arma::mat x,
     }
 
     return y;
+//The bottelneck in this computation is the computation of the cumulative 
+//density function of a univariate t-distribution with ::Rf_pt
 
 }
